<template>
  <div class="app-container">
    <!-- 查询表单区域 -->
    <el-form :model="listQuery" size="small" :inline="true" label-position="top">
      <el-row :gutter="20">
        <el-col :span="6">
          <el-form-item label="开始日期">
            <el-date-picker v-model="listQuery.startDate" value-format="yyyy-MM-dd" type="date" 
              placeholder="开始日期" style="width: 100%">
            </el-date-picker>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="结束日期">
            <el-date-picker v-model="listQuery.endDate" value-format="yyyy-MM-dd" type="date" 
              placeholder="结束日期" style="width: 100%">
            </el-date-picker>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="调出仓库">
            <el-select v-model="listQuery.warehouseId" clearable filterable 
              placeholder="调出仓库" style="width: 100%">
              <el-option :key="item.id" v-for="item in warehouseList" 
                :label="item.warehouseName" :value="item.id">
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="调出经手人">
            <el-select v-model="listQuery.outHandlerId" clearable filterable 
              placeholder="调出经手人" style="width: 100%">
              <el-option :key="item.loginId" v-for="item in userSelsctList" 
                :label="item.deptName+'_'+item.userName" :value="item.loginId">
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>

      <el-row :gutter="20">
        <el-col :span="6">
          <el-form-item label="调入仓库">
            <el-select v-model="listQuery.warehouseTargetId" clearable filterable 
              placeholder="调入仓库" style="width: 100%">
              <el-option :key="item.id" v-for="item in warehouseList" 
                :label="item.warehouseName" :value="item.id">
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="调入经手人">
            <el-select v-model="listQuery.addHandlerId" clearable filterable 
              placeholder="调入经手人" style="width: 100%">
              <el-option :key="item.loginId" v-for="item in userSelsctList" 
                :label="item.deptName+'_'+item.userName" :value="item.loginId">
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="发货状态">
            <el-select v-model="listQuery.isDelivery" clearable 
              placeholder="发货状态" style="width: 100%">
              <el-option :key="item.type" v-for="item in typeList" 
                :label="item.name" :value="item.type">
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="20">
        <el-col :span="6">
          <el-form-item label="搜索">
            <el-button style="width: 100%;" type="primary" icon="el-icon-search" 
              @click="handleFilter">搜索</el-button>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="重置">
            <el-button style="width: 100%;" icon="el-icon-refresh" type="primary" 
              @click="resetQuery">重置</el-button>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>

    <!-- 操作按钮区域 -->
    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" class="editButton" size="small" 
          icon="el-icon-plus" @click="handleCreate">添加</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" icon="el-icon-download" size="small" 
          @click="handleDownload">导出</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" icon="el-icon-delete" size="small" 
          @click="delAll">批量删除</el-button>
      </el-col>
    </el-row>

    <!-- 表格区域 -->
    <div class="border-card">
      <el-table height="450" size="small" :data="list" @selection-change="handleSelectionChange" 
        v-loading="listLoading" element-loading-text="正在查询中。。。" border fit highlight-current-row>
        <el-table-column type="selection" width="55px" align="center"></el-table-column>
        <el-table-column type="index" label="序号" header-align="center" align="center"></el-table-column>
        <el-table-column align="center" min-width="150px" label="调拨单号">
          <template slot-scope="scope">
            <router-link :to="{ name: 'requisitionDetail', params: { id: scope.row.id } }">
              <div style="color: #337ab7;cursor: pointer;">{{ scope.row.serialCode }}</div>
            </router-link>
          </template>
        </el-table-column>
        <el-table-column align="center" min-width="100px" label="调拨时间" prop="serialDate"></el-table-column>
        <el-table-column align="center" min-width="100px" label="调出仓库" prop="warehouseName"></el-table-column>
        <el-table-column align="center" min-width="100px" label="调出经手人" prop="outHandlerName"></el-table-column>
        <el-table-column align="center" min-width="100px" label="调入仓库" prop="warehouseTargetName"></el-table-column>
        <el-table-column align="center" min-width="100px" label="调入经手人" prop="addHandlerName"></el-table-column>
        <el-table-column align="center" min-width="100px" label="调拨状态">
          <template slot-scope="props">
            <span v-if="props.row.isDelivery == '0'" style="color: #67C23A;font-weight: bold;">已发货</span>
            <span v-if="props.row.isDelivery == '1'" style="color: #E6A23C;font-weight: bold;">待发货</span>
            <span v-if="props.row.isRunFinish == '2'" style="color: #E6A23C;font-weight: bold;">已作废</span>
          </template>
        </el-table-column>
        <el-table-column align="center" label="操作" width="240px" class-name="small-padding fixed-width">
          <template slot-scope="scope">
            <el-button v-if="scope.row.isDelivery == '1'" type="text" icon="el-icon-success" 
              class="openText" size="small" @click="handleExecute(scope.row)">发货</el-button>
            <el-button v-if="scope.row.isDelivery == '1'" type="text" icon="el-icon-edit" 
              class="editText" size="small" @click="handleUpdate(scope.row)">编辑</el-button>
            <el-button v-if="scope.row.isRunFinish != '0'" type="text" icon="el-icon-delete" 
              class="deleteText" size="small" @click="handleDelete(scope.row)">删除</el-button>
            <el-button v-if="scope.row.isRunFinish == '0'" type="text" icon="el-icon-close" 
              class="closeText" size="small" @click="handleCancelShow(scope.row.id)">作废</el-button>
          </template>
        </el-table-column>
      </el-table>

      <!-- 分页 -->
      <div class="pagination-container">
        <el-pagination background @size-change="handleSizeChange" @current-change="handleCurrentChange"
          :current-page="listQuery.page" :page-sizes="[10, 20, 30, 50]" :page-size="listQuery.limit"
          layout="total, sizes, prev, pager, next, jumper" :total="total">
        </el-pagination>
      </div>
    </div>

    <!-- 作废原因对话框 -->
    <el-dialog :close-on-click-modal="false" title="单据作废" :visible.sync="dialogFormVisible" width="40%">
      <el-form :rules="rules" ref="dataForm" :model="dataForm" status-icon label-position="left" label-width="80px">
        <el-form-item label="作废原因" prop="cancelMsg">
          <el-input type="textarea" :rows="2" placeholder="请输入作废原因" v-model="dataForm.cancelMsg"></el-input>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button @click="dialogFormVisible = false">取消</el-button>
        <el-button type="primary" @click="handleCancel()">确定</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listRequisition, deleteRequisition, executeRequisition, cancelRequisition } from '@/api/requisition'
import { warehouseList } from '@/api/warehouse'
import { allUserList } from '@/api/public'

export default {
  data() {
    return {
      cancelId: '',
      dialogFormVisible: false,
      dataForm: {
        cancelMsg: ''
      },
      rules: {
        cancelMsg: [{ required: true, message: '作废原因不能为空', trigger: 'blur' }]
      },
      warehouseList: [],
      userSelsctList: [],
      typeList: [
        { type: '0', name: '已发货' },
        { type: '1', name: '待发货' },
        { type: '2', name: '已作废' }
      ],
      list: [],
      delarr: [],
      multipleSelection: [],
      total: 0,
      listLoading: false,
      listQuery: {
        page: 1,
        limit: 10,
        startDate: '',
        endDate: '',
        warehouseId: '',
        outHandlerId: '',
        warehouseTargetId: '',
        addHandlerId: '',
        isDelivery: ''
      }
    }
  },
  created() {
    this.getStoreList()
    this.getAllUserList()
    this.getList()
  },
  methods: {
    handleCancelShow(id) {
      this.dialogFormVisible = true
      this.cancelId = id
      this.$nextTick(() => {
        this.dataForm.cancelMsg = ''
        this.$refs['dataForm'].clearValidate()
      })
    },
    handleCancel() {
      this.$refs['dataForm'].validate((valid) => {
        if (valid) {
          cancelRequisition({ id: this.cancelId, cancelMsg: this.dataForm.cancelMsg }).then(() => {
            this.dialogFormVisible = false
            this.$notify({
              title: '成功',
              message: '操作成功',
              type: 'success',
              duration: 2000
            })
            this.getList()
          })
        }
      })
    },
    getStoreList() {
      warehouseList().then(response => {
        this.warehouseList = response.data.data
      }).catch(() => { })
    },
    getAllUserList() {
      allUserList().then(response => {
        this.userSelsctList = response.data.data
      }).catch(() => { })
    },
    resetQuery() {
      this.listQuery = {
        page: 1,
        limit: 10,
        startDate: '',
        endDate: '',
        warehouseId: '',
        outHandlerId: '',
        warehouseTargetId: '',
        addHandlerId: '',
        isDelivery: ''
      }
      this.getList()
    },
    handleDownload() {
      window.location.href = process.env.BASE_API + '/warehouse-requisition/export'
    },
    handleCreate() {
      this.$router.push({ name: 'requisitionAdd' })
    },
    getList() {
      this.listLoading = true
      listRequisition(this.listQuery).then(response => {
        this.list = response.data.data.items
        this.total = response.data.data.total
        this.listLoading = false
      }).catch(() => {
        this.list = []
        this.total = 0
        this.listLoading = false
      })
    },
    handleFilter() {
      this.listQuery.page = 1
      this.getList()
    },
    handleSizeChange(val) {
      this.listQuery.limit = val
      this.getList()
    },
    handleCurrentChange(val) {
      this.listQuery.page = val
      this.getList()
    },
    handleUpdate(row) {
      this.$router.push({ name: 'requisitionEdit', params: { id: row.id }})
    },
    handleExecute(row) {
      this.$confirm('确认调拨吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        executeRequisition({ ids: row.id }).then(response => {
          this.$notify({
            title: '成功',
            message: '调拨成功',
            type: 'success',
            duration: 2000
          })
          this.getList()
        })
      }).catch(() => { })
    },
    executeAll() {
      const length = this.multipleSelection.length
      if (length > 0) {
        this.$confirm('确认调拨吗？', '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(() => {
          for (let i = 0; i < length; i++) {
            this.delarr.push(this.multipleSelection[i].id)
          }
          const ids = this.delarr.join(',')
          executeRequisition({ ids: ids }).then(() => {
            this.$notify({
              title: '成功',
              message: '调拨成功',
              type: 'success',
              duration: 2000
            })
            this.getList()
          })
        })
      } else {
        this.$notify({
          title: '提示',
          message: '请选择要调拨的信息！',
          type: 'warning'
        })
      }
    },
    handleDelete(row) {
      this.$confirm('确认删除吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        deleteRequisition({ ids: row.id }).then(response => {
          this.$notify({
            title: '成功',
            message: '删除成功',
            type: 'success',
            duration: 2000
          })
          this.getList()
        })
      }).catch(() => { })
    },
    delAll() {
      const length = this.multipleSelection.length
      if (length > 0) {
        this.$confirm('确认删除吗？', '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(() => {
          for (let i = 0; i < length; i++) {
            this.delarr.push(this.multipleSelection[i].id)
          }
          const ids = this.delarr.join(',')
          deleteRequisition({ ids: ids }).then(() => {
            this.$notify({
              title: '成功',
              message: '删除成功',
              type: 'success',
              duration: 2000
            })
            this.getList()
          })
        })
      } else {
        this.$notify({
          title: '提示',
          message: '请选择要删除的信息！',
          type: 'warning'
        })
      }
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    }
  }
}
</script>